module.exports = function(grunt) {

  // Project configuration.
  grunt.initConfig({

    clean: { main: { src: ['dist*'] } },

    sass: {
      options: { precision: 5 },
      main: { files: [{ expand: true, cwd: 'src/_scss', src: '**.scss',  dest: 'dist/css', ext: '.css' }] }
    },

    postcss: {
      options: { processors: [ require('autoprefixer')({browsers: 'last 2 versions'}) ] },
      main: { src: 'dist/css/*.css' }
    },

    cssmin: {
      main: { files: [{expand: true, src: ['dist/css/*.css', '!dist/css/*.min.css'], ext: '.min.css'}] }
    },



    ejs: {
      main: { files: [{ expand: true, cwd: "src/_ejs", src: ['*.ejs','!_*.ejs'], dest: "dist/", ext: ".html" }] }
    },

    jsbeautifier: {
      files: ["dist/**/*.html"],
      options: { html: { indentSize: 2, preserveNewlines: true } }
    },


    uglify: {
      main: {
        files: {
          'dist/js/icy-modal.min.js': ['src/js/icy-modal.js']
        }
      }
    },


    copy: {
      main: { files: [{ expand: true, cwd: 'src', src: ['**', '!_*', '!_*/**'], dest: 'dist' }] }
    },

    connect: { main: { uses_defaults: {}, options: { base: 'dist' } } },

    watch: {
      options: { spawn: false, livereload : true },
      all: { files: ['src/**/*'], tasks: ['build'] }
    },

    bower: {
      dev: {
        dest: 'dist/bower_components'
      }
    }
  });

  // Load plugins
  grunt.loadNpmTasks('grunt-contrib-clean');

  grunt.loadNpmTasks('grunt-sass');
  grunt.loadNpmTasks('grunt-postcss');
  grunt.loadNpmTasks('grunt-contrib-cssmin');

  grunt.loadNpmTasks('grunt-ejs');
  grunt.loadNpmTasks("grunt-jsbeautifier");

  grunt.loadNpmTasks('grunt-contrib-uglify');

  grunt.loadNpmTasks('grunt-contrib-copy');
  grunt.loadNpmTasks('grunt-contrib-connect');
  grunt.loadNpmTasks('grunt-contrib-watch');

  grunt.loadNpmTasks('main-bower-files');


  // Tasks
  grunt.registerTask(
    'build',
    '...',
    ['copy', 'sass', 'postcss', 'cssmin', 'ejs', 'jsbeautifier', 'bower', 'uglify']
  );


  grunt.registerTask(
    'default',
    '...',
    ['build', 'connect', 'watch']
  );
};
